You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@drill.apache.org by me...@apache.org on 2015/06/23 21:00:06 UTC

[2/5] drill git commit: DRILL-3285: Part 3--Invert beforeFirstBatch -> ! afterFirstBatch.

DRILL-3285: Part 3--Invert beforeFirstBatch -> ! afterFirstBatch.


Project: http://git-wip-us.apache.org/repos/asf/drill/repo
Commit: http://git-wip-us.apache.org/repos/asf/drill/commit/e050f1e1
Tree: http://git-wip-us.apache.org/repos/asf/drill/tree/e050f1e1
Diff: http://git-wip-us.apache.org/repos/asf/drill/diff/e050f1e1

Branch: refs/heads/master
Commit: e050f1e17f32d60960b01757455face52050bed3
Parents: d040429
Author: dbarclay <db...@maprtech.com>
Authored: Fri Jun 12 18:42:14 2015 -0700
Committer: Mehant Baid <me...@gmail.com>
Committed: Mon Jun 22 13:05:04 2015 -0700

----------------------------------------------------------------------
 .../main/java/org/apache/drill/jdbc/impl/DrillCursor.java    | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/drill/blob/e050f1e1/exec/jdbc/src/main/java/org/apache/drill/jdbc/impl/DrillCursor.java
----------------------------------------------------------------------
diff --git a/exec/jdbc/src/main/java/org/apache/drill/jdbc/impl/DrillCursor.java b/exec/jdbc/src/main/java/org/apache/drill/jdbc/impl/DrillCursor.java
index a54422e..81b2de5 100644
--- a/exec/jdbc/src/main/java/org/apache/drill/jdbc/impl/DrillCursor.java
+++ b/exec/jdbc/src/main/java/org/apache/drill/jdbc/impl/DrillCursor.java
@@ -70,8 +70,8 @@ class DrillCursor implements Cursor {
    */
   private boolean returnTrueForNextCallToNext = false;
 
-  /** Whether on first batch.  (Re skipping spurious empty batches.) */
-  private boolean beforeFirstBatch = true;
+  /** Whether after first batch.  (Re skipping spurious empty batches.) */
+  private boolean afterFirstBatch = false;
 
   /** ... corresponds to current schema. */
   private DrillColumnMetaDataList columnMetaDataList;
@@ -156,7 +156,7 @@ class DrillCursor implements Cursor {
         while ( qrb != null
                 && ( qrb.getHeader().getRowCount() == 0
                      || qrb.getData() == null )
-                && ! beforeFirstBatch ) {
+                && afterFirstBatch ) {
           // Empty message--dispose of and try to get another.
           logger.warn( "Spurious batch read: {}", qrb );
 
@@ -178,7 +178,7 @@ class DrillCursor implements Cursor {
           }
         }
 
-        beforeFirstBatch = false;
+        afterFirstBatch = true;
 
         if (qrb == null) {
           // End of batches--clean up, set state to done, report after last row.